@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of MIDI files
 
-our $VERSION = '0.1400';
+our $VERSION = '0.1401';
 
 use Moo;
 use strictures 2;
@@ -389,7 +389,7 @@ sub populate {
                     # Convert MIDI numbers to named notes.
                     my $note_text = $self->note_convert($choice);
 
-                    $playback .= "\t$n\t$channel\t$choice $note_text\n";
+                    $playback .= "\t$n\t$channel\t$choice ($note_text)\n";
 
                     # Add each chosen note to the score
                     for my $note ( split /\s+/, $choice ) {
@@ -431,7 +431,7 @@ sub populate {
                 # Convert MIDI numbers to named notes.
                 my $note_text = $self->note_convert($phrase);
 
-                $playback .= "\t$n\t$channel\t$phrase $note_text\n";
+                $playback .= "\t$n\t$channel\t$phrase ($note_text)\n";
 
                 my @phrase = split /\s/, $phrase;
                 push @all, @phrase;
@@ -553,7 +553,7 @@ MIDI::Ngram - Find the top repeated note phrases of MIDI files
 
 =head1 VERSION
 
-version 0.1400
+version 0.1401
 
 =head1 SYNOPSIS
 
@@ -611,6 +611,10 @@ C<MIDI::Ngram> parses a given list of MIDI files, finds the top
 repeated note phrases, builds the analysis, transition network, and
 renders to a MIDI file if desired.
 
+Currently, this only works right for MIDI files with channels of
+B<single notes>.  Channels with simultaneous notes (as in, chords) are
+not handled correctly. Ugh!
+
 =head1 ATTRIBUTES
 
 =head2 in_file
